@@ -441,9 +441,7 @@ gsm_get_dialog (GsmDialogLogoutType type,
                 guint32             activate_time)
 {
         GsmLogoutDialog *logout_dialog;
-#if !GTK_CHECK_VERSION (3, 0, 0)
         GtkWidget       *dialog_image;
-#endif
         GtkWidget       *hbox;
         const char      *primary_text;
         const char      *icon_name;
@@ -522,19 +520,12 @@ gsm_get_dialog (GsmDialogLogoutType type,
         default:
                 g_assert_not_reached ();
         }
-#if !GTK_CHECK_VERSION (3, 0, 0)
-        dialog_image = gtk_message_dialog_get_image (GTK_MESSAGE_DIALOG (logout_dialog));
-#endif
 
-#if GTK_CHECK_VERSION (3, 0, 0)
+        dialog_image = gtk_message_dialog_get_image (GTK_MESSAGE_DIALOG (logout_dialog));
+
         hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-        hbox = gtk_hbox_new (FALSE, 0);
-#endif
         logout_dialog->priv->progressbar = gtk_progress_bar_new ();
-#if GTK_CHECK_VERSION (3, 0, 0)
         gtk_progress_bar_set_show_text (GTK_PROGRESS_BAR (logout_dialog->priv->progressbar), TRUE);
-#endif
         gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (logout_dialog->priv->progressbar), 1.0);
         gtk_box_pack_start (GTK_BOX (hbox),
                             logout_dialog->priv->progressbar,
@@ -542,10 +533,8 @@ gsm_get_dialog (GsmDialogLogoutType type,
         gtk_widget_show_all (hbox);
         gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (logout_dialog))), hbox);
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
         gtk_image_set_from_icon_name (GTK_IMAGE (dialog_image),
                                       icon_name, GTK_ICON_SIZE_DIALOG);
-#endif
         gtk_window_set_icon_name (GTK_WINDOW (logout_dialog), icon_name);
         gtk_window_set_position (GTK_WINDOW (logout_dialog), GTK_WIN_POS_CENTER_ALWAYS);
         gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (logout_dialog), primary_text);
